@@ -1,6 +1,6 @@
 /* This module implements the relp sess object.
  *
- * Copyright 2008-2015 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2018 by Rainer Gerhards and Adiscon GmbH.
  *
  * To clarify on session handling: There is no upper limit of the number
  * of sessions, except for system ressources. Some left-over comment
@@ -164,10 +164,14 @@ relpSessDestruct(relpSess_t **ppThis)
 		free(pUnackedToDel);
 	}
 
+	if(pThis->pCurrRcvFrame != NULL)
+		relpFrameDestruct(&pThis->pCurrRcvFrame);
+
 	free(pThis->srvPort);
 	free(pThis->srvAddr);
 	free(pThis->clientIP);
 	free(pThis->pristring);
+	free(pThis->caCertFile);
 	free(pThis->ownCertFile);
 	free(pThis->privKeyFile);
 	relpSessFreePermittedPeers(pThis);
@@ -188,7 +192,7 @@ relpSessDestruct(relpSess_t **ppThis)
 relpRetVal
 relpSessAcceptAndConstruct(relpSess_t **ppThis, relpSrv_t *pSrv, int sock)
 {
-	relpSess_t *pThis;
+	relpSess_t *pThis = NULL;
 
 	ENTER_RELPFUNC;
 	assert(ppThis != NULL);
@@ -231,7 +235,7 @@ relpSessRcvData(relpSess_t *pThis)
 	CHKRet(relpTcpRcv(pThis->pTcp, rcvBuf, &lenBuf));
 
 	if(lenBuf == 0) {
-		pThis->pEngine->dbgprint("server closed relp session %p, session broken\n", pThis);
+		pThis->pEngine->dbgprint("server closed relp session %p, session broken\n", (void*)pThis);
 		/* even though we had a "normal" close, it is unexpected at this
 		 * stage. Consequently, we consider the session to be broken, because
 		 * the recovery action is the same no matter how it is broken.
@@ -240,7 +244,8 @@ relpSessRcvData(relpSess_t *pThis)
 		ABORT_FINALIZE(RELP_RET_SESSION_BROKEN);
 	} else if ((int) lenBuf == -1) { /* I don't know why we need to cast to int, but we must... */
 		if(errno != EAGAIN) {
-			pThis->pEngine->dbgprint("errno %d during relp session %p, session broken\n", errno,pThis);
+			pThis->pEngine->dbgprint("errno %d during relp session %p, session broken\n",
+				errno, (void*)pThis);
 			pThis->sessState = eRelpSessState_BROKEN;
 			ABORT_FINALIZE(RELP_RET_SESSION_BROKEN);
 		}
@@ -279,7 +284,7 @@ relpSessSendResponse(relpSess_t *pThis, relpTxnr_t txnr, unsigned char *pData, s
 finalize_it:
 	if(iRet != RELP_RET_OK) {
 		if(iRet == RELP_RET_IO_ERR) {
-			pThis->pEngine->dbgprint("relp session %p is broken, io error\n", pThis);
+			pThis->pEngine->dbgprint("relp session %p is broken, io error\n", (void*)pThis);
 			pThis->sessState = eRelpSessState_BROKEN;
 			}
 
@@ -400,7 +405,8 @@ relpSessAddUnacked(relpSess_t *pThis, relpSendbuf_t *pSendbuf)
 			pThis->pEngine->dbgprint("Warning: exceeding window size, max %d, curr %d\n",
 						 pThis->lenUnackedLst, pThis->sizeWindow);
 	}
-	pThis->pEngine->dbgprint("ADD sess %p unacked %d, sessState %d\n", pThis, pThis->lenUnackedLst, pThis->sessState);
+	pThis->pEngine->dbgprint("ADD sess %p unacked %d, sessState %d\n",
+		(void*)pThis, pThis->lenUnackedLst, pThis->sessState);
 
 finalize_it:
 	LEAVE_RELPFUNC;
@@ -433,7 +439,8 @@ relpSessDelUnacked(relpSess_t *pThis, relpSessUnacked_t *pUnackedLstEntry)
 
 	free(pUnackedLstEntry);
 
-	pThis->pEngine->dbgprint("DEL sess %p unacked %d, sessState %d\n", pThis, pThis->lenUnackedLst, pThis->sessState);
+	pThis->pEngine->dbgprint("DEL sess %p unacked %d, sessState %d\n",
+		(void*)pThis, pThis->lenUnackedLst, pThis->sessState);
 	LEAVE_RELPFUNC;
 }
 
@@ -451,7 +458,7 @@ relpSessGetUnacked(relpSess_t *pThis, relpSendbuf_t **ppSendbuf, relpTxnr_t txnr
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
 	assert(ppSendbuf != NULL);
-	
+
 	for(  pUnackedEtry = pThis->pUnackedLstRoot
 	    ; pUnackedEtry != NULL && pUnackedEtry->pSendbuf->txnr != txnr
 	    ; pUnackedEtry = pUnackedEtry->pNext)
@@ -586,7 +593,7 @@ relpSessRawSendCommand(relpSess_t *pThis, unsigned char *pCmd, size_t lenCmd,
 	iRet = relpSendbufSendAll(pSendbuf, pThis, 1);
 
 	if(iRet == RELP_RET_IO_ERR) {
-		pThis->pEngine->dbgprint("relp session %p flagged as broken, IO error\n", pThis);
+		pThis->pEngine->dbgprint("relp session %p flagged as broken, IO error\n", (void*)pThis);
 		pThis->sessState = eRelpSessState_BROKEN;
 		ABORT_FINALIZE(RELP_RET_SESSION_BROKEN);
 	}
@@ -646,7 +653,7 @@ relpSessTryReestablish(relpSess_t *pThis)
 
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
-	assert(pThis->sessState = eRelpSessState_BROKEN);
+	assert(pThis->sessState == eRelpSessState_BROKEN);
 
 	CHKRet(relpTcpAbortDestruct(&pThis->pTcp));
 	CHKRet(relpSessConnect(pThis, pThis->protFamily, pThis->srvPort, pThis->srvAddr));
@@ -659,7 +666,7 @@ relpSessTryReestablish(relpSess_t *pThis)
 	pUnackedEtry = pThis->pUnackedLstRoot;
 	if(pUnackedEtry != NULL)
 		pThis->pEngine->dbgprint("relp session %p reestablished, now resending %d unacked frames\n",
-					  pThis, pThis->lenUnackedLst);
+					  (void*)pThis, pThis->lenUnackedLst);
 	while(pUnackedEtry != NULL) {
 		pThis->pEngine->dbgprint("resending frame '%s'\n", pUnackedEtry->pSendbuf->pData + 9
 								   - pUnackedEtry->pSendbuf->lenTxnr);
@@ -954,7 +961,7 @@ relpSessSetPermittedPeers(relpSess_t *pThis, relpPermittedPeers_t *pPeers)
 	ENTER_RELPFUNC;
 	int i;
 	RELPOBJ_assert(pThis, Sess);
-	
+
 	relpSessFreePermittedPeers(pThis);
 	if(pPeers->nmemb != 0) {
 		if((pThis->permittedPeers.name =
@@ -1022,7 +1029,7 @@ relpSessSetGnuTLSPriString(relpSess_t *pThis, char *pristr)
 {
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
-	
+
 	free(pThis->pristring);
 	if(pristr == NULL) {
 		pThis->pristring = NULL;
@@ -1039,7 +1046,7 @@ relpSessSetCACert(relpSess_t *pThis, char *cert)
 {
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
-	
+
 	free(pThis->caCertFile);
 	if(cert == NULL) {
 		pThis->caCertFile = NULL;
@@ -1056,7 +1063,7 @@ relpSessSetOwnCert(relpSess_t *pThis, char *cert)
 {
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
-	
+
 	free(pThis->ownCertFile);
 	if(cert == NULL) {
 		pThis->ownCertFile = NULL;
@@ -1073,7 +1080,7 @@ relpSessSetPrivKey(relpSess_t *pThis, char *cert)
 {
 	ENTER_RELPFUNC;
 	RELPOBJ_assert(pThis, Sess);
-	
+
 	free(pThis->privKeyFile);
 	if(cert == NULL) {
 		pThis->privKeyFile = NULL;
