@@ -1,6 +1,6 @@
 /* The relp server.
  *
- * Copyright 2008-2016 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2018 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -70,6 +70,7 @@ relpSrvConstruct(relpSrv_t **ppThis, relpEngine_t *pEngine)
 	pThis->privKey = NULL;
 	pThis->permittedPeers.nmemb = 0;
 	pThis->maxDataSize = RELP_DFLT_MAX_DATA_SIZE;
+	pThis->oversizeMode = RELP_DFLT_OVERSIZE_MODE;
 
 	*ppThis = pThis;
 
@@ -96,6 +97,8 @@ relpSrvDestruct(relpSrv_t **ppThis)
 
 	if(pThis->pLstnPort != NULL)
 		free(pThis->pLstnPort);
+	if(pThis->pLstnAddr != NULL)
+		free(pThis->pLstnAddr);
 
 	free(pThis->pristring);
 	free(pThis->caCertFile);
@@ -164,6 +167,21 @@ relpRetVal relpSrvSetMaxDataSize(relpSrv_t *pThis, size_t maxSize) {
 	LEAVE_RELPFUNC;
 }
 
+relpRetVal ATTR_NONNULL()
+relpSrvSetOversizeMode(relpSrv_t *const pThis, const int oversizeMode)
+{
+	ENTER_RELPFUNC;
+	RELPOBJ_assert(pThis, Srv);
+	if(   oversizeMode != RELP_OVERSIZE_ABORT
+	   && oversizeMode != RELP_OVERSIZE_TRUNCATE
+	   && oversizeMode != RELP_OVERSIZE_ACCEPT) {
+		ABORT_FINALIZE(RELP_RET_PARAM_ERROR);
+	}
+	pThis->oversizeMode = oversizeMode;
+finalize_it:
+	LEAVE_RELPFUNC;
+}
+
 /* set the listen port inside the relp server. If NULL is provided, the default port
  * is used. The provided string is always copied, it is the caller's duty to
  * free the passed-in string.
@@ -189,6 +207,31 @@ finalize_it:
 	LEAVE_RELPFUNC;
 }
 
+/* set the address inside the relp server. If NULL is provided, the server
+ * will bind to all interfaces. The provided string is always copied, it is the caller's duty to
+ * free the passed-in string.
+ * perlei, 2018-04-19
+ */
+relpRetVal
+relpSrvSetLstnAddr(relpSrv_t *pThis, unsigned char *pLstnAddr)
+{
+	ENTER_RELPFUNC;
+	RELPOBJ_assert(pThis, Srv);
+
+	/* first free old value */
+	if(pThis->pLstnAddr != NULL)
+		free(pThis->pLstnAddr);
+	pThis->pLstnAddr = NULL;
+
+	if(pLstnAddr != NULL) {
+		if((pThis->pLstnAddr = (unsigned char*) strdup((char*)pLstnAddr)) == NULL)
+			ABORT_FINALIZE(RELP_RET_OUT_OF_MEMORY);
+	}
+
+finalize_it:
+	LEAVE_RELPFUNC;
+}
+
 /* mode==NULL is valid and means "no change" */
 relpRetVal
 relpSrvSetAuthMode(relpSrv_t *pThis, char *mode)
@@ -295,22 +338,22 @@ relpRetVal
 relpSrvEnableTLS2(relpSrv_t __attribute__((unused)) *pThis)
 {
 	ENTER_RELPFUNC;
-#ifdef ENABLE_TLS
+#if defined(ENABLE_TLS) || defined(ENABLE_TLS_OPENSSL)
 	pThis->bEnableTLS = 1;
 #else
 	iRet = RELP_RET_ERR_NO_TLS;
-#endif /* #ifdef ENABLE_TLS */
+#endif /* #ifdef ENABLE_TLS | ENABLE_TLS_OPENSSL */
 	LEAVE_RELPFUNC;
 }
 relpRetVal
 relpSrvEnableTLSZip2(relpSrv_t __attribute__((unused)) *pThis)
 {
 	ENTER_RELPFUNC;
-#ifdef ENABLE_TLS
+#if defined(ENABLE_TLS) || defined(ENABLE_TLS_OPENSSL)
 	pThis->bEnableTLSZip = 1;
 #else
 	iRet = RELP_RET_ERR_NO_TLS;
-#endif /* #ifdef ENABLE_TLS */
+#endif /* #ifdef ENABLE_TLS | ENABLE_TLS_OPENSSL */
 	LEAVE_RELPFUNC;
 }
 void
@@ -364,7 +407,9 @@ relpSrvRun(relpSrv_t *pThis)
 		CHKRet(relpTcpSetPermittedPeers(pTcp, &(pThis->permittedPeers)));
 	}
 	CHKRet(relpTcpLstnInit(pTcp, (pThis->pLstnPort == NULL) ?
-		(unsigned char*) RELP_DFLT_PORT : pThis->pLstnPort, pThis->ai_family));
+		(unsigned char*) RELP_DFLT_PORT : pThis->pLstnPort,
+		(unsigned char*) pThis->pLstnAddr,
+		pThis->ai_family));
 
 	pThis->pTcp = pTcp;
 
